==> percona-server-mongodb_4.0.18.orig.tar.gz: percona-server-mongodb-4.0.18-11/aws-sdk-cpp/aws-cpp-sdk-cloudformation/include/aws/cloudformation/CloudFormationErrors.h <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#pragma once

#include <aws/core/client/CoreErrors.h>
#include <aws/cloudformation/CloudFormation_EXPORTS.h>

namespace Aws
{
namespace CloudFormation
{
enum class CloudFormationErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,
  
  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ALREADY_EXISTS= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CHANGE_SET_NOT_FOUND,
  CREATED_BUT_MODIFIED,
  INSUFFICIENT_CAPABILITIES,
  INVALID_CHANGE_SET_STATUS,
  INVALID_OPERATION,
  LIMIT_EXCEEDED,
  NAME_ALREADY_EXISTS,
  OPERATION_ID_ALREADY_EXISTS,
  OPERATION_IN_PROGRESS,
  OPERATION_NOT_FOUND,
  STACK_INSTANCE_NOT_FOUND,
  STACK_SET_NOT_EMPTY,
  STACK_SET_NOT_FOUND,
  STALE_REQUEST,
  TOKEN_ALREADY_EXISTS
};
namespace CloudFormationErrorMapper
{
  AWS_CLOUDFORMATION_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace CloudFormation
} // namespace Aws

==> percona-server-mongodb_5.0.9.orig.tar.gz: percona-server-mongodb-5.0.9-8/aws-sdk-cpp/aws-cpp-sdk-cloudformation/include/aws/cloudformation/CloudFormationErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/cloudformation/CloudFormation_EXPORTS.h>

namespace Aws
{
namespace CloudFormation
{
enum class CloudFormationErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ALREADY_EXISTS= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CHANGE_SET_NOT_FOUND,
  CREATED_BUT_MODIFIED,
  C_F_N_REGISTRY,
  INSUFFICIENT_CAPABILITIES,
  INVALID_CHANGE_SET_STATUS,
  INVALID_OPERATION,
  INVALID_STATE_TRANSITION,
  LIMIT_EXCEEDED,
  NAME_ALREADY_EXISTS,
  OPERATION_ID_ALREADY_EXISTS,
  OPERATION_IN_PROGRESS,
  OPERATION_NOT_FOUND,
  OPERATION_STATUS_CHECK_FAILED,
  STACK_INSTANCE_NOT_FOUND,
  STACK_SET_NOT_EMPTY,
  STACK_SET_NOT_FOUND,
  STALE_REQUEST,
  TOKEN_ALREADY_EXISTS,
  TYPE_NOT_FOUND
};

class AWS_CLOUDFORMATION_API CloudFormationError : public Aws::Client::AWSError<CloudFormationErrors>
{
public:
  CloudFormationError() {}
  CloudFormationError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<CloudFormationErrors>(rhs) {}
  CloudFormationError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<CloudFormationErrors>(rhs) {}
  CloudFormationError(const Aws::Client::AWSError<CloudFormationErrors>& rhs) : Aws::Client::AWSError<CloudFormationErrors>(rhs) {}
  CloudFormationError(Aws::Client::AWSError<CloudFormationErrors>&& rhs) : Aws::Client::AWSError<CloudFormationErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace CloudFormationErrorMapper
{
  AWS_CLOUDFORMATION_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace CloudFormation
} // namespace Aws
